function foo() {
    return ()=>{
        function Bar__2() {}
        Bar__2.qux = '';
        return Bar__2;
    };
}
